@@ -11,6 +11,19 @@ struct _ExamplePluginPrivate
 
 HD_DEFINE_PLUGIN_MODULE (ExamplePlugin, example_plugin, HD_TYPE_STATUS_MENU_ITEM);
 
+static void
+visibility_changed (HDStatusMenuItem *plugin)
+{
+  gboolean is_visible;
+
+  /* the compositor moves invisible windows off the screen, so we can use that
+   * to determine whether the status area is visible */
+  g_object_get (G_OBJECT (plugin), "status-area-visible", &is_visible, NULL);
+
+  g_debug ("status area visibility changed; now %s",
+           is_visible ? "visible" : "INvisible");
+}
+
 static void
 example_plugin_class_finalize (ExamplePluginClass *klass)
 {
@@ -46,6 +59,12 @@ example_plugin_init (ExamplePlugin *menu_item)
   gtk_widget_show (button);
   gtk_container_add (GTK_CONTAINER (menu_item), button);
 
+  /* Set up a handler to be called when the status area itself is hidden. This
+   * can be used to avoid unnecessary work when a full-screen program hides the
+   * status area */
+  g_signal_connect_swapped (G_OBJECT (menu_item), "notify::status-area-visible",
+                            G_CALLBACK (visibility_changed), menu_item);
+
   /* To set (or unset) the status area icon */
   hd_status_plugin_item_set_status_area_icon (HD_STATUS_PLUGIN_ITEM (menu_item),
 		  		              icon);
